summaryrefslogtreecommitdiffstats
path: root/src/server/CompiledPatch.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/server/CompiledPatch.hpp')
-rw-r--r--src/server/CompiledPatch.hpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/server/CompiledPatch.hpp b/src/server/CompiledPatch.hpp
index 5f699d2d..0a5752a5 100644
--- a/src/server/CompiledPatch.hpp
+++ b/src/server/CompiledPatch.hpp
@@ -28,7 +28,7 @@
namespace Ingen {
namespace Server {
-class ConnectionImpl;
+class EdgeImpl;
class NodeImpl;
/** All information required about a node to execute it in an audio thread.
@@ -69,10 +69,10 @@ class CompiledPatch : public std::vector<CompiledNode>
, public boost::noncopyable
{
public:
- typedef std::vector<ConnectionImpl*> QueuedConnections;
+ typedef std::vector<EdgeImpl*> QueuedEdges;
- /** All (audio context => other context) connections */
- std::vector<ConnectionImpl*> queued_connections;
+ /** All (audio context => other context) edges */
+ std::vector<EdgeImpl*> queued_edges;
};
} // namespace Server